@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000042-000001"; }
+sub IDENTIFICATION { return "000001-000042-000002"; }
 
 sub preference { return 1000; }
 
@@ -33,3 +33,10 @@ sub cmdhelp {
 		'EDIT <objectname>' => 'Edit object with <objectname>'
 		];
 }
+
+sub cmdcomplete {
+	my ($obj,$text,$line,$start) = @_;
+	return () unless $obj->{-dbi}->current;
+	return qw/EDIT/ if $line =~ /^\s*[A-Z]*$/i;
+	return ();
+}
