@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000034-000001"; }
+sub IDENTIFICATION { return "000001-000034-000002"; }
 
 sub preference { return 2000; }
 
@@ -37,3 +37,9 @@ sub cmdhelp {
 	];
 }
 
+sub cmdcomplete {
+	my ($obj,$text,$line,$start) = @_;
+	return qw/HISTORY/ if $line =~ /^\s*(SHOW|CLEAR)\s+\S*$/i;
+	return qw/SHOW CLEAR/ if $line =~ /^\s*[A-Z]*$/i;
+	return ();
+}
