@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000013-000002"; }
+sub IDENTIFICATION { return "000001-000013-000003"; }
 
 sub preference { return 1000; }
 
@@ -21,6 +21,7 @@ sub handle_action {
 			$action{action} = 'SQL';
 			$action{type} = 'select';
 			$action{sql} = $action{cmd};
+			$action{explain} = 1 if $action{cmd} =~ /^explain\s+/i;
 		} elsif ($action{cmd} =~ /^((delete|insert|update|create|drop|begin|alter|truncate|grant|revoke)\s+.*|vacuum)$/i) {
 			$action{action} = 'SQL';
 			$action{type} = 'do';
@@ -45,6 +46,14 @@ sub objectlist {
 sub cmdcomplete {
 	my ($obj,$text,$line,$start) = @_;
 	return () unless $obj->{-dbi}->current;
+	return ('(',qw/VALUES SELECT/) if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+$/i;
+	return qw/VALUES SELECT/ if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+(\([^)]+\))?\s*[A-Z]*$/i;
+	return ('(') if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+(\([^)]+\)\s*)?VALUES\s*$/i;
+	return ($obj->objectlist('FUNCTION',$text),$obj->objectlist('SEQ',$text)) if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+(\([^)]+\))?\s*VALUES/i;
+	return ($obj->objectlist('CONTEXT',$text),$obj->objectlist('SEQ',$text)) if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+(\([^)]+\))?\s*SELECT/i;
+	return ($obj->objectlist('FIELDS',$1.'.')) if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+/i;
+	return qw/SELECT/ if $line =~ /^\s*EXPLAIN\s+PLAN\s+FOR\s+\S*$/i;
+	return qw/FOR/ if $line =~ /^\s*EXPLAIN\s+PLAN\s+\S*$/i;
 	return qw/PLAN/ if $line =~ /^\s*EXPLAIN\s+\S*$/i;
 	return $obj->objectlist($1) if $line =~ /^\s*DROP\s+(PACKAGE\s+BODY|\S+)\s+\S*$/i;
 	return qw/WHERE/ if $line =~ /^\s*DELETE\s+FROM\s+\S+\s+\S*$/i;
@@ -56,7 +65,12 @@ sub cmdcomplete {
 	return ('BODY',$obj->objectlist('PACKAGE')) if $line =~ /^\s*DROP\s+PACKAGE\s+\S*$/i;
 	return qw/TABLE SEQUENCE VIEW FUNCTION PACKAGE PROCEDURE TRIGGER/ if $line =~ /^\s*(DROP|CREATE|ALTER)\s+\S*$/i;
 	return qw/SELECT EXPLAIN DELETE INSERT UPDATE CREATE DROP BEGIN ALTER TRUNCATE GRANT REVOKE/ if $line =~ /^\s*[A-Z]*$/i;
-	return ($obj->objectlist('CONTEXT',$text),$obj->objectlist('SEQ',$text)) if $line =~ /^\s*(SELECT|DELETE|UPDATE)\s+/i;
-	return ($obj->objectlist('FIELDS',$1.'.'),$obj->objectlist('SEQ',$text)) if $line =~ /^\s*INSERT\s+INTO\s+(\S+)\s+/i;
+	return ($obj->objectlist('CONTEXT',$text),$obj->objectlist('SEQ',$text)) if $line =~ /^\s*(SELECT|DELETE|UPDATE|EXPLAIN)\s+/i;
 }
 
+sub cmdhelp {
+	return [
+		'EXPLAIN PLAN FOR <select>' => 'Explain (Oracle) plan for executing query <select>'
+	];
+
+}
