@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000003-000003"; }
+sub IDENTIFICATION { return "000001-000003-000004"; }
 
 sub preference { return 1000; }
 
@@ -33,6 +33,7 @@ sub cmdhelp {
 
 sub cmdcomplete {
 	my ($obj,$text,$line,$start) = @_;
-	return qw/QUIT EXIT LOGOUT/ if $line =~ /^\s*[A-Z]*$/i;
+	return qw/q/ if $line =~ /^\s*\\\S*$/i;
+	return qw/QUIT EXIT LOGOUT \q/ if $line =~ /^\s*[A-Z]*$/i;
 	return ();
 }
