@@ -5,12 +5,12 @@ use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 use Text::FormatTable;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000020-000001"; }
+sub IDENTIFICATION { return "000001-000020-000002"; }
 
 sub preference { return 0; }
 
@@ -36,7 +36,12 @@ sub handle_action {
 				($a->[1] eq $b->[1]) 
 				? ($a->[2] cmp $b->[2]) 
 				: ($a->[1] cmp $b->[1]) } @$ret) {
-				$table->row($_->[1],$_->[2],$_->[3]);
+				if (($action{type} eq 'object' or
+				  $action{type} eq lc $_->[3]) and
+				  $action{mask} and
+				  $_->[1] =~ /$action{mask}/i) {
+					$table->row($_->[1],$_->[2],$_->[3]);
+				}
 			}
 		}
 		$sth->finish;
